Estimates the Individual Treatment Effect using Augmented Inverse Probability Weighting given a response vector, a treatment vector, a features matrix, an estimation model for the propensity score and estimation model for the outcome.
estimate_ite_aipw(y, z, X, learner_ps = "SL.xgboost", learner_y = "SL.xgboost")A list of ITE estimates.
An observed response vector.
A treatment vector.
A features matrix.
A estimation model for the propensity score.
A estimation model for the outcome.