Learn R Programming

CRE (version 0.2.7)

estimate_ite_tpoisson: Estimate the Individual Treatment Effect (ITE) using T-Poisson regression

Description

Estimates the Individual Treatment Effect using Poisson regression given a response vector, a treatment vector, and a features matrix.

Usage

estimate_ite_tpoisson(y, z, X, offset)

Value

A vector of ITE estimates.

Arguments

y

An observed response vector.

z

A treatment vector.

X

A features matrix.

offset

A name of the covariate to use as offset (i.e. “x1”) to model the corresponding outcome rate. NULL to model directly the outcome counts without offset.