Estimates the Individual Treatment Effect using Poisson regression given a response vector, a treatment vector, and a features matrix.
estimate_ite_tpoisson(y, z, X, offset)A vector of ITE estimates.
An observed response vector.
A treatment vector.
A features matrix.
A name of the covariate to use as offset (i.e. “x1”) to
model the corresponding outcome rate. NULL to model directly the outcome
counts without offset.